==> nodejs_interop-0.4.0.tar.gz: lib/src/io/file_system.dart <==
part of nodejs_interop.io;

/// A [Node.js](https://nodejs.org) file system implementation.
class FileSystem extends f.FileSystem {

  /// Creates a new Node.js file system.
  const FileSystem();

  /// Creates a [Directory] object pointing to the current working directory.
  @override
  Directory get currentDirectory => directory(process.cwd());

  /// Sets the current working directory to the specified [path]. The new value set can be either a [Directory] or a [String].
  @override
  set currentDirectory(path) => process.chdir(getPath(path));

  /// Tests if [FileSystemEntity.watch] is supported on the current system.
  @override
  bool get isWatchSupported => FileSystemEntity.isWatchSupported;

  /// An object for manipulating paths in this file system.
  @override
  p.Context get path => new p.Context(current: process.cwd(), style: const Platform().isWindows ? p.Style.windows : p.Style.posix);

  /// The system temporary directory.
  @override
  Directory get systemTempDirectory => directory(_os.tmpdir());

  /// Returns a reference to a [Directory] at [path].
  /// [path] can be either a [String], a [Uri], or a [FileSystemEntity].
  @override
  Directory directory(path) => new Directory(getPath(path));

  /// Returns a reference to a [File] at [path].
  /// [path] can be either a [String], a [Uri], or a [FileSystemEntity].
  @override
  File file(path) => new File(getPath(path));

  /// Checks whether two paths refer to the same object in the file system.
  /// Returns a [Future] that completes with the [bool] result.
  ///
  /// Comparing a link to its target returns `false`, as does comparing two links that point to the same target.
  /// To check the target of a link, use [Link.target] explicitly to fetch it.
  /// Directory links appearing inside a path are followed, though, to find the file system object.
  ///
  /// Completes the returned future with an error if one of the paths points to an object that does not exist.
  @override
  Future<bool> identical(String path1, String path2) => FileSystemEntity.identical(path1, path2);

  /// Synchronously checks whether two paths refer to the same object in the file system.
  ///
  /// Comparing a link to its target returns `false`, as does comparing two links that point to the same target.
  /// To check the target of a link, use [Link.target] explicitly to fetch it.
  /// Directory links appearing inside a path are followed, though, to find the file system object.
  ///
  /// Throws an error if one of the paths points to an object that does not exist.
  @override
  bool identicalSync(String path1, String path2) => FileSystemEntity.identicalSync(path1, path2);

  /// Returns a reference to a [Link] at [path].
  /// [path] can be either a [String], a [Uri], or a [FileSystemEntity].
  @override
  Link link(path) => new Link(getPath(path));

  /// Calls the operating system's `stat()` function on the specified [path].
  ///
  /// Returns a [Future<FileStat>] object containing the data returned by `stat()`.
  /// If the call fails, completes the future with a [FileStat] object with `.type` set to [f.FileSystemEntityType.NOT_FOUND] and the other fields invalid.
  @override
  Future<FileStat> stat(String path) => FileStat.stat(path);

  /// Synchronously calls the operating system's `stat()` function on the specified [path].
  ///
  /// Returns a [FileStat] object containing the data returned by `stat()`.
  /// If the call fails, returns a [FileStat] object with `.type` set to [f.FileSystemEntityType.NOT_FOUND] and the other fields invalid.
  @override
  FileStat statSync(String path) => FileStat.statSync(path);

  /// Finds the type of file system entity that a [path] points to.
  ///
  /// [f.FileSystemEntityType.LINK] will only be returned if [followLinks] is `false`, and [path] points to a link.
  /// If the [path] does not point to a file system object or an error occurs then [f.FileSystemEntityType.NOT_FOUND] is returned.
  @override
  Future<f.FileSystemEntityType> type(String path, {bool followLinks = true}) => FileSystemEntity.type(path, followLinks: followLinks);

  /// Syncronously finds the type of file system entity that a [path] points to.
  ///
  /// [f.FileSystemEntityType.LINK] will only be returned if [followLinks] is `false`, and [path] points to a link.
  /// If the [path] does not point to a file system object or an error occurs then [f.FileSystemEntityType.NOT_FOUND] is returned.
  @override
  f.FileSystemEntityType typeSync(String path, {bool followLinks = true}) => FileSystemEntity.typeSync(path, followLinks: followLinks);
}

==> nodejs_interop-0.5.0.tar.gz: lib/src/io/file_system.dart <==
part of nodejs_interop.io;

/// A generic representation of the file system.
class FileSystem extends f.FileSystem {

  /// Creates a new file system.
  const FileSystem();

  /// A [Directory] object pointing to the current working directory.
  @override
  Directory get currentDirectory => Directory.current;

  /// Sets the current working directory to the specified [path]. The new value set can be either a [Directory] or a [String].
  @override
  set currentDirectory(path) => process.chdir(getPath(path));

  /// Tests if [FileSystemEntity.watch] is supported on the current system.
  @override
  bool get isWatchSupported => FileSystemEntity.isWatchSupported;

  /// An object for manipulating paths in this file system.
  @override
  p.Context get path => new p.Context(current: process.cwd(), style: const Platform().isWindows ? p.Style.windows : p.Style.posix);

  /// The system temporary directory.
  @override
  Directory get systemTempDirectory => Directory.systemTemp;

  /// Returns a reference to a [Directory] at [path].
  /// [path] can be either a [String], a [Uri], or a [FileSystemEntity].
  @override
  Directory directory(path) => new Directory(getPath(path));

  /// Returns a reference to a [File] at [path].
  /// [path] can be either a [String], a [Uri], or a [FileSystemEntity].
  @override
  File file(path) => new File(getPath(path));

  /// Checks whether two paths refer to the same object in the file system.
  /// Returns a [Future] that completes with the [bool] result.
  ///
  /// Comparing a link to its target returns `false`, as does comparing two links that point to the same target.
  /// To check the target of a link, use [Link.target] explicitly to fetch it.
  /// Directory links appearing inside a path are followed, though, to find the file system object.
  ///
  /// Completes the returned future with an error if one of the paths points to an object that does not exist.
  @override
  Future<bool> identical(String path1, String path2) => FileSystemEntity.identical(path1, path2);

  /// Synchronously checks whether two paths refer to the same object in the file system.
  ///
  /// Comparing a link to its target returns `false`, as does comparing two links that point to the same target.
  /// To check the target of a link, use [Link.target] explicitly to fetch it.
  /// Directory links appearing inside a path are followed, though, to find the file system object.
  ///
  /// Throws an error if one of the paths points to an object that does not exist.
  @override
  bool identicalSync(String path1, String path2) => FileSystemEntity.identicalSync(path1, path2);

  /// Returns a reference to a [Link] at [path].
  /// [path] can be either a [String], a [Uri], or a [FileSystemEntity].
  @override
  Link link(path) => new Link(getPath(path));

  /// Calls the operating system's `stat()` function on the specified [path].
  ///
  /// Returns a [Future<FileStat>] object containing the data returned by `stat()`.
  /// If the call fails, completes the future with a [FileStat] object with `.type` set to [f.FileSystemEntityType.NOT_FOUND] and the other fields invalid.
  @override
  Future<FileStat> stat(String path) => FileStat.stat(path);

  /// Synchronously calls the operating system's `stat()` function on the specified [path].
  ///
  /// Returns a [FileStat] object containing the data returned by `stat()`.
  /// If the call fails, returns a [FileStat] object with `.type` set to [f.FileSystemEntityType.NOT_FOUND] and the other fields invalid.
  @override
  FileStat statSync(String path) => FileStat.statSync(path);

  /// Finds the type of file system entity that a [path] points to.
  ///
  /// [f.FileSystemEntityType.LINK] will only be returned if [followLinks] is `false`, and [path] points to a link.
  /// If the [path] does not point to a file system object or an error occurs then [f.FileSystemEntityType.NOT_FOUND] is returned.
  @override
  Future<f.FileSystemEntityType> type(String path, {bool followLinks = true}) => FileSystemEntity.type(path, followLinks: followLinks);

  /// Syncronously finds the type of file system entity that a [path] points to.
  ///
  /// [f.FileSystemEntityType.LINK] will only be returned if [followLinks] is `false`, and [path] points to a link.
  /// If the [path] does not point to a file system object or an error occurs then [f.FileSystemEntityType.NOT_FOUND] is returned.
  @override
  f.FileSystemEntityType typeSync(String path, {bool followLinks = true}) => FileSystemEntity.typeSync(path, followLinks: followLinks);
}
